pub struct Request<'a, P> {
pub headers: RequestHeaders<'a>,
pub raw_headers: Vec<RequestHeader<'a>>,
pub payload: P,
}Expand description
Parsed Request.
Fields
headers: RequestHeaders<'a>raw_headers: Vec<RequestHeader<'a>>payload: Pthis field usually contains an iterator yielding the lines of the payload, but Request needs the type Parameter because of Limitations of impl Trait